@@ -92,7 +92,7 @@ has actionCfg => sub {
             label => trm('Add User'),
             action => 'popup',
             addToContextMenu => true,
-            name => 'userFormAdd',
+            key => 'add',
             popupTitle => trm('New User'),
             backend => {
                 plugin => 'UserForm',
@@ -106,7 +106,7 @@ has actionCfg => sub {
             action => 'popup',
             addToContextMenu => true,
             defaultAction => true,
-            name => 'userFormEdit',
+            key => 'edit',
             popupTitle => trm('Edit User'),
             actionHandler => sub {
                 my $self = shift;
@@ -134,7 +134,7 @@ has actionCfg => sub {
             key => 'delete',
             actionHandler => sub {
                 my $self = shift;
-                my $args = shift;                
+                my $args = shift;
                 my $id = $args->{selection}{cbuser_id};
                 die mkerror(4992,trm("You have to select a user first"))
                     if not $id;
